import { ref, computed } from 'vue';
import { useI18n } from 'vue-i18n';

export function useLanguage() {
  const { locale, t } = useI18n();
  
  // 语言选项 - 使用国际化标签
  const languageOptions = computed(() => [
    { label: t('language.zh'), value: 'zh', key: 'zh' },
    { label: t('language.zhTW'), value: 'zh-TW', key: 'zh-TW' },
    { label: t('language.en'), value: 'en', key: 'en' },
    { label: t('language.ja'), value: 'ja', key: 'jp' },
    { label: t('language.de'), value: 'de', key: 'de' }
  ]);
  
  // 当前选中的语言
  const currentLanguage = ref(locale.value);
  
  // 当前语言的显示名称
  const currentLanguageLabel = computed(() => {
    const option = languageOptions.value.find(opt => opt.value === currentLanguage.value);
    return option ? option.label : t('language.zh');
  });
  
  // 当前语言的简写代码（用于资源路径）
  const currentLang = computed(() => {
    switch (locale.value) {
      case 'zh-TW':
        return 'tw';
      case 'ja':
        return 'jp';
      case 'en':
        return 'en';
      case 'de':
        return 'de';
      default:
        return 'cn';
    }
  });
  

  
  // 切换语言的方法
  const changeLanguage = (lang) => {
    locale.value = lang;
    currentLanguage.value = lang;
    localStorage.setItem('language', lang);
    window.location.reload();
  };
  
  // 获取浏览器语言
  const getBrowserLanguage = () => {
    const language = navigator.language || navigator.userLanguage;
    const lang = language.toLowerCase();
    
    if (lang.includes('zh')) {
      if (lang.includes('tw') || lang.includes('hk')) {
        return 'zh-TW';
      }
      return 'zh';
    }
    if (lang.includes('ja')) {
      return 'ja';
    }
    if (lang.includes('de')) {
      return 'de';
    }
    return 'en';
  };
  
  // 初始化语言
  const initLanguage = () => {
    const savedLanguage = localStorage.getItem('language') || getBrowserLanguage();
    locale.value = savedLanguage;
    currentLanguage.value = savedLanguage;
    localStorage.setItem('language', savedLanguage);
  };
  
  return {
    languageOptions,
    currentLanguage,
    currentLanguageLabel,
    currentLang,
    changeLanguage,
    initLanguage,
    t
  };
}
